<template>
  <div>
    <el-popover
      ref="popover"
      width="800"
      placement="bottom-start"
      trigger="click"
      popper-class="mod-menu__icon-popover"
    >
      <el-tabs v-model="activeTab">
        <el-tab-pane
          v-for="tab in tabs"
          :key="tab.title"
          :label="tab.title"
          :name="tab.title"
        >
          <div class="mod-menu__icon-list">
            <el-button
              v-for="(item, index) in tab.icons"
              :key="index"
              :class="{ 'is-active': item === currentValue }"
              @click="onIconChange(item)"
            >
              <i :class="item" aria-hidden="true" />
            </el-button>
          </div>
        </el-tab-pane>
      </el-tabs>
    </el-popover>
    <el-input
      v-popover:popover
      v-bind="$attrs"
      :value="currentValue"
      placeholder="图标"
      @input="onInput"
    />
  </div>
</template>

<script>
import {
  FILE_ICONS,
  EDITOR_ICONS,
  CHART_ICONS,
  COMMON_ICONS,
} from '@/plugins/icons'
export default {
  inheritAttrs: false,
  props: {
    value: {
      type: String,
      default: '',
    },
  },
  data() {
    return {
      tabs: [
        { title: '文件类图标', icons: FILE_ICONS },
        { title: '文本编辑类图标', icons: EDITOR_ICONS },
        { title: '数据类图标', icons: CHART_ICONS },
        { title: '通用类', icons: COMMON_ICONS },
      ],
      activeTab: '文件类图标',
    }
  },
  watch: {
    value: {
      immediate: true,
      handler(value) {
        this.currentValue = value
      },
    },
  },
  methods: {
    onIconChange(value) {
      this.$emit('input', value)
      this.$emit('change', value)
    },
    onInput(e) {
      this.$emit('input', e)
      this.$emit('change', e)
      // this.onValidate()
    },
  },
}
</script>

<style lang="scss">
.mod-menu__icon-popover {
  .mod-menu__icon-list {
    height: 300px;
    overflow: auto;
    .el-button {
      margin: 0 10px 10px 0;
    }
  }
}
</style>
